@@ -15,7 +15,7 @@ import itertools
 import pyisbn
 import re
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 __all__ = [
     'FatRecord',
@@ -518,6 +518,10 @@ class marcdict(dict):
 
         return flatten(result)
 
+    def firstvalue(self, *fieldspecs):
+        result = self.values(*fieldspecs)
+        return result[0] if result else None
+
 
 class FincMarc(FatRecord):
     """
